@@ -5,14 +5,13 @@ use fil_actors_runtime::runtime::{ActorCode, Runtime};
 use fil_actors_runtime::{
     actor_error, resolve_to_id_addr, wasm_trampoline, ActorDowncast, ActorError, Array,
 };
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::RawBytes;
 use fvm_shared::actor::builtin::Type;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::{BigInt, Sign};
-use fvm_shared::blockstore::Blockstore;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
-use fvm_shared::error::ExitCode::ErrTooManyProveCommits as ErrChannelStateUpdateAfterSettled;
 use fvm_shared::{MethodNum, METHOD_CONSTRUCTOR, METHOD_SEND};
 use num_derive::FromPrimitive;
 use num_traits::FromPrimitive;
@@ -25,6 +24,8 @@ wasm_trampoline!(Actor);
 mod state;
 mod types;
 
+const ERR_USR_CHANNEL_STATE_UPDATE_AFTER_SETTLED: ExitCode = ExitCode::new(32);
+
 // * Updated to specs-actors commit: f47f461b0588e9f0c20c999f6f129c85d669a7aa (v3.0.2)
 
 /// Payment Channel actor methods available
@@ -59,7 +60,7 @@ impl Actor {
             Array::<(), _>::new_with_bit_width(rt.store(), LANE_STATES_AMT_BITWIDTH)
                 .flush()
                 .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to create empty AMT")
+                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to create empty AMT")
                 })?;
 
         rt.create(&State::new(from, to, empty_arr_cid))?;
@@ -74,20 +75,20 @@ impl Actor {
     {
         let resolved = resolve_to_id_addr(rt, raw).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve address {}", raw),
             )
         })?;
 
-        let code_cid = rt
-            .get_actor_code_cid(&resolved)
-            .ok_or_else(|| actor_error!(ErrIllegalArgument, "no code for address {}", resolved))?;
+        let code_cid = rt.get_actor_code_cid(&resolved).ok_or_else(|| {
+            actor_error!(USR_ILLEGAL_ARGUMENT, "no code for address {}", resolved)
+        })?;
 
         let typ = rt.resolve_builtin_actor_type(&code_cid);
 
         if typ != Some(Type::Account) {
             Err(actor_error!(
-                ErrForbidden,
+                USR_FORBIDDEN,
                 "actor {} must be an account, was {} ({:?})",
                 raw,
                 code_cid,
@@ -120,18 +121,18 @@ impl Actor {
         let sig = sv
             .signature
             .as_ref()
-            .ok_or_else(|| actor_error!(ErrIllegalArgument, "voucher has no signature"))?;
+            .ok_or_else(|| actor_error!(USR_ILLEGAL_ARGUMENT, "voucher has no signature"))?;
 
         if st.settling_at != 0 && rt.curr_epoch() >= st.settling_at {
             return Err(ActorError::new(
-                ErrChannelStateUpdateAfterSettled,
+                ERR_USR_CHANNEL_STATE_UPDATE_AFTER_SETTLED,
                 "no vouchers can be processed after settling at epoch".to_string(),
             ));
         }
 
         if params.secret.len() > MAX_SECRET_SIZE {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "secret must be at most 256 bytes long"
             ));
         }
@@ -143,40 +144,40 @@ impl Actor {
 
         // Validate signature
         rt.verify_signature(sig, &signer, &sv_bz).map_err(|e| {
-            e.downcast_default(ExitCode::ErrIllegalArgument, "voucher signature invalid")
+            e.downcast_default(ExitCode::USR_ILLEGAL_ARGUMENT, "voucher signature invalid")
         })?;
 
         let pch_addr = rt.message().receiver();
         let svpch_id_addr = rt.resolve_address(&sv.channel_addr).ok_or_else(|| {
             actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "voucher payment channel address {} does not resolve to an ID address",
                 sv.channel_addr
             )
         })?;
         if pch_addr != svpch_id_addr {
-            return Err(actor_error!(ErrIllegalArgument;
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                     "voucher payment channel address {} does not match receiver {}",
                     svpch_id_addr, pch_addr));
         }
 
         if rt.curr_epoch() < sv.time_lock_min {
-            return Err(actor_error!(ErrIllegalArgument; "cannot use this voucher yet"));
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT; "cannot use this voucher yet"));
         }
 
         if sv.time_lock_max != 0 && rt.curr_epoch() > sv.time_lock_max {
-            return Err(actor_error!(ErrIllegalArgument; "this voucher has expired"));
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT; "this voucher has expired"));
         }
 
         if sv.amount.sign() == Sign::Minus {
-            return Err(actor_error!(ErrIllegalArgument;
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                     "voucher amount must be non-negative, was {}", sv.amount));
         }
 
         if !sv.secret_pre_image.is_empty() {
             let hashed_secret: &[u8] = &rt.hash_blake2b(&params.secret);
             if hashed_secret != sv.secret_pre_image.as_slice() {
-                return Err(actor_error!(ErrIllegalArgument; "incorrect secret"));
+                return Err(actor_error!(USR_ILLEGAL_ARGUMENT; "incorrect secret"));
             }
         }
 
@@ -192,7 +193,7 @@ impl Actor {
 
         rt.transaction(|st: &mut State, rt| {
             let mut l_states = Array::load(&st.lane_states, rt.store()).map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load lane states")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load lane states")
             })?;
 
             // Find the voucher lane, create and insert it in sorted order if necessary.
@@ -201,7 +202,7 @@ impl Actor {
 
             let mut lane_state = if let Some(state) = lane_state {
                 if state.nonce >= sv.nonce {
-                    return Err(actor_error!(ErrIllegalArgument;
+                    return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                         "voucher has an outdated nonce, existing: {}, voucher: {}, cannot redeem",
                         state.nonce, sv.nonce));
                 }
@@ -216,18 +217,18 @@ impl Actor {
             let mut redeemed_from_others = BigInt::default();
             for merge in sv.merges {
                 if merge.lane == sv.lane {
-                    return Err(actor_error!(ErrIllegalArgument;
+                    return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                         "voucher cannot merge lanes into it's own lane"));
                 }
                 let mut other_ls = find_lane(&l_states, merge.lane)?
                     .ok_or_else(|| {
-                        actor_error!(ErrIllegalArgument;
+                        actor_error!(USR_ILLEGAL_ARGUMENT;
                         "voucher specifies invalid merge lane {}", merge.lane)
                     })?
                     .clone();
 
                 if other_ls.nonce >= merge.nonce {
-                    return Err(actor_error!(ErrIllegalArgument;
+                    return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                             "merged lane in voucher has outdated nonce, cannot redeem"));
                 }
 
@@ -235,7 +236,7 @@ impl Actor {
                 other_ls.nonce = merge.nonce;
                 l_states.set(merge.lane, other_ls).map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to store lane {}", merge.lane),
                     )
                 })?;
@@ -253,12 +254,12 @@ impl Actor {
             let new_send_balance = balance_delta + &st.to_send;
 
             if new_send_balance < TokenAmount::from(0) {
-                return Err(actor_error!(ErrIllegalArgument;
+                return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                     "voucher would leave channel balance negative"));
             }
 
             if new_send_balance > rt.current_balance() {
-                return Err(actor_error!(ErrIllegalArgument;
+                return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                     "not enough funds in channel to cover voucher"));
             }
 
@@ -277,13 +278,13 @@ impl Actor {
 
             l_states.set(lane_id, lane_state).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to store lane {}", lane_id),
                 )
             })?;
 
             st.lane_states = l_states.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to save lanes")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to save lanes")
             })?;
             Ok(())
         })
@@ -298,7 +299,7 @@ impl Actor {
             rt.validate_immediate_caller_is([st.from, st.to].iter())?;
 
             if st.settling_at != 0 {
-                return Err(actor_error!(ErrIllegalState; "channel already settling"));
+                return Err(actor_error!(USR_ILLEGAL_STATE; "channel already settling"));
             }
 
             st.settling_at = rt.curr_epoch() + SETTLE_DELAY;
@@ -319,7 +320,7 @@ impl Actor {
         rt.validate_immediate_caller_is(&[st.from, st.to])?;
 
         if st.settling_at == 0 || rt.curr_epoch() < st.settling_at {
-            return Err(actor_error!(ErrForbidden; "payment channel not settling or settled"));
+            return Err(actor_error!(USR_FORBIDDEN; "payment channel not settling or settled"));
         }
 
         // send ToSend to `to`
@@ -342,12 +343,12 @@ where
     BS: Blockstore,
 {
     if id > MAX_LANE {
-        return Err(actor_error!(ErrIllegalArgument; "maximum lane ID is 2^63-1"));
+        return Err(actor_error!(USR_ILLEGAL_ARGUMENT; "maximum lane ID is 2^63-1"));
     }
 
     ls.get(id).map_err(|e| {
         e.downcast_default(
-            ExitCode::ErrIllegalState,
+            ExitCode::USR_ILLEGAL_STATE,
             format!("failed to load lane {}", id),
         )
     })
@@ -380,7 +381,7 @@ impl ActorCode for Actor {
                 Self::collect(rt)?;
                 Ok(RawBytes::default())
             }
-            _ => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
+            _ => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
         }
     }
 }
